pub fn init()Expand description
Initialize the dynpatch runtime with default settings
This sets up the global registry with sensible defaults.
For more control, use RuntimeBuilder.
pub fn init()Initialize the dynpatch runtime with default settings
This sets up the global registry with sensible defaults.
For more control, use RuntimeBuilder.